@@ -9,8 +9,8 @@ app$setInputs(navbar_ID = "Likelihood",
               outc_sel = "y",
               dist_sel = "bernoulli")
 app$setInputs(likelihood_navlist_ID = "Predictors")
-app$setInputs(pred_mainCP_sel = c("week", "trt"),
-              pred_mainPP_sel = "ID")
+app$setInputs(pred_mainPL_sel = c("week", "trt"),
+              pred_mainGL_sel = "ID")
 app$setInputs(pred_int_build = c("week", "trt"),
               pred_int_add = "click")
 app$setInputs(navbar_ID = "Prior")
